//******************************************************************
//
// Copyright 2014 Intel Corporation.
//
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

#ifndef NAMEDEFS_H_
#define NAMEDEFS_H_

#define EDISON_RESOURCE_INTERFACE "core.edison.resources"
#define TEMPERATURE_RESOURCE_TYPE "room.temperature"
#define LIGHT_RESOURCE_TYPE "ambient.light"
#define LED_RESOURCE_TYPE "platform.led"
#define TEMPERATURE_RESOURCE_ENDPOINT "/temperature"
#define LIGHT_RESOURCE_ENDPOINT "/ambientlight"
#define LED_RESOURCE_ENDPOINT "/led"
#define TEMPERATURE_RESOURCE_KEY "temperature"
#define LIGHT_RESOURCE_KEY "ambientlight"
#define LED_RESOURCE_KEY "switch"

#endif /* NAMEDEFS_H_ */
